@@ -1,5 +1,3 @@
-import requests
-
 CONFIG = {
     "DEV": {
         "LOCAL": {
@@ -65,7 +63,6 @@ class Config:
 
         for runtime_env, urls in CONFIG[env].items():
             try:
-                requests.get(url=urls["TEST_URL"], timeout=0.5)
                 setattr(self, "RUNTIME_ENV", runtime_env)
                 for key, url in urls.items():
                     setattr(self, key, url)
